@@ -5,7 +5,7 @@ use utf8;
 use Kavorka;
 use Regexp::Grammars;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 method AST::JSON::X() {
@@ -124,7 +124,7 @@ my $Parser = qr {
 }xms;
 
 
-method Json_Parse( Str $String ) {
+method Json_Parse( $String ) {
     if( $String =~ $Parser ) {
         $/{JSON}->X();
     }
